@@ -8,7 +8,6 @@ use cosmwasm_std::{
     ensure, ensure_ne, to_binary, BankMsg, Binary, Coin, CosmosMsg, Deps, DepsMut, DistributionMsg,
     Empty, Env, MessageInfo, Order, Response, StakingMsg, StdResult,
 };
-use cw0::Expiration;
 use cw1::CanExecuteResponse;
 use cw1_whitelist::{
     contract::{
@@ -20,6 +19,7 @@ use cw1_whitelist::{
 };
 use cw2::{get_contract_version, set_contract_version};
 use cw_storage_plus::Bound;
+use cw_utils::Expiration;
 use semver::Version;
 
 use crate::error::ContractError;
@@ -409,7 +409,7 @@ pub fn query_all_allowances(
     // we use raw addresses here....
     let start = start_after.map(Bound::exclusive);
 
-    let res: StdResult<Vec<AllowanceInfo>> = ALLOWANCES
+    let allowances = ALLOWANCES
         .range(deps.storage, start, None, Order::Ascending)
         .filter(|item| {
             if let Ok((_, allow)) = item {
@@ -420,16 +420,14 @@ pub fn query_all_allowances(
         })
         .take(limit)
         .map(|item| {
-            item.and_then(|(k, allow)| {
-                Ok(AllowanceInfo {
-                    spender: String::from_utf8(k)?,
-                    balance: allow.balance,
-                    expires: allow.expires,
-                })
+            item.map(|(addr, allow)| AllowanceInfo {
+                spender: addr.into(),
+                balance: allow.balance,
+                expires: allow.expires,
             })
         })
-        .collect();
-    Ok(AllAllowancesResponse { allowances: res? })
+        .collect::<StdResult<Vec<_>>>()?;
+    Ok(AllAllowancesResponse { allowances })
 }
 
 // return a list of all permissions here
@@ -441,19 +439,17 @@ pub fn query_all_permissions(
     let limit = calc_limit(limit);
     let start = start_after.map(Bound::exclusive);
 
-    let res: StdResult<Vec<PermissionsInfo>> = PERMISSIONS
+    let permissions = PERMISSIONS
         .range(deps.storage, start, None, Order::Ascending)
         .take(limit)
         .map(|item| {
-            item.and_then(|(k, perm)| {
-                Ok(PermissionsInfo {
-                    spender: String::from_utf8(k)?,
-                    permissions: perm,
-                })
+            item.map(|(addr, perm)| PermissionsInfo {
+                spender: addr.into(),
+                permissions: perm,
             })
         })
-        .collect();
-    Ok(AllPermissionsResponse { permissions: res? })
+        .collect::<StdResult<Vec<_>>>()?;
+    Ok(AllPermissionsResponse { permissions })
 }
 
 // Migrate contract if version is lower than current version
@@ -479,9 +475,9 @@ mod tests {
     };
     use cosmwasm_std::{coin, coins, OwnedDeps, StakingMsg, SubMsg, Timestamp};
 
-    use cw0::NativeBalance;
     use cw1_whitelist::msg::AdminListResponse;
     use cw2::{get_contract_version, ContractVersion};
+    use cw_utils::NativeBalance;
 
     use crate::state::Permissions;
 
